Task
====

.. autoclass:: deepint.core.Task
   :exclude-members:
   :members:

.. autoclass:: deepint.core.TaskStatus
   :exclude-members:
   :members:

.. autoclass:: deepint.core.task.TaskInfo
   :exclude-members:
   :members: